import React from "react";
import { OverridableComponent } from "../util/types/index.js";
import { LinkPanelDescriptionProps } from "./LinkPanelDescription.js";
import { LinkPanelTitleProps } from "./LinkPanelTitle.js";
export interface LinkPanelProps extends React.AnchorHTMLAttributes<HTMLAnchorElement> {
    /**
     * Panel content
     */
    children?: React.ReactNode;
    /**
     * Adds border to panel if true
     * @default true
     */
    border?: boolean;
}
interface LinkPanelComponentType extends OverridableComponent<LinkPanelProps, HTMLAnchorElement> {
    /**
     * @see 🏷️ {@link LinkPanelDescriptionProps}
     * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
     */
    Title: OverridableComponent<LinkPanelTitleProps, HTMLDivElement>;
    /**
     * @see 🏷️ {@link LinkPanelDescriptionProps}
     */
    Description: React.ForwardRefExoticComponent<LinkPanelDescriptionProps & React.RefAttributes<HTMLDivElement>>;
}
/**
 * A component that displays a link panel.
 *
 * @see [📝 Documentation](https://aksel.nav.no/komponenter/core/linkpanel)
 * @see 🏷️ {@link LinkPanelProps}
 * @see [🤖 OverridableComponent](https://aksel.nav.no/grunnleggende/kode/overridablecomponent) support
 *
 * @example
 * ```jsx
 * <LinkPanel href="#" border>
 *   <LinkPanel.Title>Arbeidssøker eller permittert</LinkPanel.Title>
 *   <LinkPanel.Description>
 *     Om jobb, registrering, CV, dagpenger og feriepenger av dagpenger
 *   </LinkPanel.Description>
 * </LinkPanel>
 * ```
 */
export declare const LinkPanelComponent: OverridableComponent<LinkPanelProps, HTMLAnchorElement>;
declare const LinkPanel: LinkPanelComponentType;
export default LinkPanel;
